@@ -76,6 +76,12 @@ export class ReferenceData extends Model {
       foreignKey: 'designationId',
     });
 
+    this.belongsToMany(models.Survey, {
+      through: models.ProcedureTypeSurvey,
+      as: 'surveys',
+      foreignKey: 'procedureTypeId',
+    });
+
     this.belongsToMany(this, {
       as: 'parent',
       through: 'reference_data_relations',
@@ -197,7 +203,7 @@ export class ReferenceData extends Model {
     return null; // syncs everywhere
   }
 
-  static async buildSyncLookupQueryDetails() {
+  static buildSyncLookupQueryDetails() {
     return null; // syncs everywhere
   }
 }
